@@ -6,6 +6,8 @@
 #ifndef KPUBLICTRANSPORT_COUNTRYBOUNDINGBOX_P_H
 #define KPUBLICTRANSPORT_COUNTRYBOUNDINGBOX_P_H
 
+#include "kpublictransport_export.h"
+
 #include <cstdint>
 
 class QRectF;
@@ -21,8 +23,10 @@ struct CountryBoundingBoxData {
     int16_t maxLat;
 };
 
-/** Look up bounding box for country with the given ISO 3166-1 alpha 2 code. */
-[[nodiscard]] QRectF boundingBoxForCountry(QStringView countryCode);
+/** Look up bounding box for country with the given ISO 3166-1 alpha 2 code.
+ *  @internal exported for QML plugin
+ */
+[[nodiscard]] KPUBLICTRANSPORT_EXPORT QRectF boundingBoxForCountry(QStringView countryCode);
 
 }
 
